@@ -1,7 +1,7 @@
 
 from bravaorm.utils.inflector import Inflector
 from bravaorm.context.database import DataBase
-from bravaorm.entity.datatype import ListType
+import bravaorm.entity.datatype as datatype
 from bravaorm.utils.log import *
 
 import re
@@ -165,60 +165,63 @@ class Connection():
         return _selects_stetaments, " ".join(_joins_stetaments)
 
     def __format_include_query__(self, obj, include):
-
         _include_key = self._klass[include]
         _include_class = self._klass[include]()
+        if obj[_include_key.reference].value:
+            if self._select:
+                _include_select = ", ".join([f"{c.replace(f'{include}.', '')} AS '{c.replace(f'{include}.', '')}'" for c in self._select if self.__is__include_select__(include, c)])
+                if not all([f"'{pk}'" in _include_select for pk in _include_class.__metadata__['pk']]):
+                    _pk_select = ", ".join([f"{pk} AS '{pk}'" for pk in _include_class.__metadata__['pk']])
+                    _include_select = f"{_include_select}, {_pk_select}"
+            else:
+                _include_select = ", ".join([f"{field} AS '{field}'" for field in _include_class.__dict__ if not field.startswith("_") and not _include_class[field].__class__.__name__.startswith("Obj")])
 
-        if self._select:
-            _include_select = ", ".join([f"{c.replace(f'{include}.', '')} AS '{c.replace(f'{include}.', '')}'" for c in self._select if self.__is__include_select__(include, c)])
-            if not all([f"'{pk}'" in _include_select for pk in _include_class.__metadata__['pk']]):
-                _pk_select = ", ".join([f"{pk} AS '{pk}'" for pk in _include_class.__metadata__['pk']])
-                _include_select = f"{_include_select}, {_pk_select}"
-        else:
-            _include_select = ", ".join([f"{field} AS '{field}'" for field in _include_class.__dict__ if not field.startswith("_") and not _include_class[field].__class__.__name__.startswith("Obj")])
+            if isinstance(obj[_include_key.reference], datatype.Int):
+                _default_condition = f'{include}.{_include_key.key} = {obj[_include_key.reference].value}'
+            else:
+                _default_condition = f"{include}.{_include_key.key} = '{obj[_include_key.reference].value}'"
 
-
-        _default_condition = f'{include}.{_include_key.key} = {obj[_include_key.reference].value}'
-
-        __conditions_include = " AND ".join([w for w in self._where if self.__is__join_or_include_codition__(include, w)]) if self._where else ""
-
-        _where = []
-        if len(__conditions_include)>0:
-            _where.append(f"( {_default_condition} AND {__conditions_include} )")
-            _orwhere = '' if len(self._orwhere) == 0 else ' OR '.join([f"( {_default_condition} AND {' AND '.join([w for w in conditions if self.__is__join_or_include_codition__(include, w)])} )" for block, conditions in self._orwhere.items()])
-            if _orwhere != '':
-                _where.append(_orwhere)
-        else:
-            _where.append(_default_condition)
-
-        def ReplaceData(stetament):
-            rule = f"\S[a-zA-Z]+_{self._table}.[a-zA-Z]+_?[a-zA-Z]+ | {self._table}.[a-zA-Z]+_?[a-zA-Z]+"
-            match = re.findall(rule, stetament)
-            for value in match:
-                if value.strip().startswith(self._table):
-                    key = value.strip().split(".")[1]
-                    stetament = stetament.replace(value, str(obj[key].value))
-            return stetament
-
-        if _include_key.__class__.__name__ != "ObjListOfMany":
-            stetament = ReplaceData(f"SELECT {_include_select} FROM {include} WHERE {' OR '.join(_where)}")
-        else:
-            _where = ""
             __conditions_include = " AND ".join([w for w in self._where if self.__is__join_or_include_codition__(include, w)]) if self._where else ""
+
+            _where = []
             if len(__conditions_include)>0:
-                _where = f"WHERE ({__conditions_include})"
-                _orwhere = '' if len(self._orwhere) == 0 else ' OR '.join([f"({' AND '.join([w for w in conditions if self.__is__join_or_include_codition__(include, w)])} )" for block, conditions in self._orwhere.items()])
-                if len(_orwhere)>0:
-                    _where = f"t{_where} OR {_orwhere}"
-            stetament = f"SELECT {_include_select} FROM {_include_key.table} {include} INNER JOIN {_include_key.intermediate} inter_{_include_key.intermediate} ON (inter_{_include_key.intermediate}.{_include_key.rel_key} = {include}.{_include_key.key} AND inter_{_include_key.intermediate}.{_include_key.ref_key} = {obj[ _include_key.reference].value}) {_where}"
-        return stetament
+                _where.append(f"( {_default_condition} AND {__conditions_include} )")
+                _orwhere = '' if len(self._orwhere) == 0 else ' OR '.join([f"( {_default_condition} AND {' AND '.join([w for w in conditions if self.__is__join_or_include_codition__(include, w)])} )" for block, conditions in self._orwhere.items()])
+                if _orwhere != '':
+                    _where.append(_orwhere)
+            else:
+                _where.append(_default_condition)
+
+            def ReplaceData(stetament):
+                rule = f"\S[a-zA-Z]+_{self._table}.[a-zA-Z]+_?[a-zA-Z]+ | {self._table}.[a-zA-Z]+_?[a-zA-Z]+"
+                match = re.findall(rule, stetament)
+                for value in match:
+                    if value.strip().startswith(self._table):
+                        if '.' in value:
+                            key = value.strip().split(".")[1]
+                            stetament = stetament.replace(value, str(obj[key].value))
+                return stetament
+
+            if _include_key.__class__.__name__ != "ObjListOfMany":
+                stetament = ReplaceData(f"SELECT {_include_select} FROM {include} WHERE {' OR '.join(_where)}")
+            else:
+                _where = ""
+                __conditions_include = " AND ".join([w for w in self._where if self.__is__join_or_include_codition__(include, w)]) if self._where else ""
+                if len(__conditions_include)>0:
+                    _where = f"WHERE ({__conditions_include})"
+                    _orwhere = '' if len(self._orwhere) == 0 else ' OR '.join([f"({' AND '.join([w for w in conditions if self.__is__join_or_include_codition__(include, w)])} )" for block, conditions in self._orwhere.items()])
+                    if len(_orwhere)>0:
+                        _where = f"t{_where} OR {_orwhere}"
+                stetament = f"SELECT {_include_select} FROM {_include_key.table} {include} INNER JOIN {_include_key.intermediate} inter_{_include_key.intermediate} ON (inter_{_include_key.intermediate}.{_include_key.rel_key} = {include}.{_include_key.key} AND inter_{_include_key.intermediate}.{_include_key.ref_key} = {obj[ _include_key.reference].value}) {_where}"
+            return stetament
+        return None
 
 
     def __is_join__(self, table_name):
-        return table_name in self._join or table_name in self._inner
+        return (not self._join is None and table_name in self._join) or (not self._inner is None and table_name in self._inner)
 
     def __is_include__(self, table_name):
-        return table_name in self._include
+        return not self._include is None and table_name in self._include
 
     def __is__main_select__(self, field):
         if not '.' in field:
@@ -434,7 +437,7 @@ class Connection():
         if class_name:
             _class = getattr(__import__(f'model.{class_name.lower()}', fromlist=[class_name]), class_name)
             _klass = _class()
-            result = ListType(_class).add([_class(**item) for item in result])
+            result = datatype.ListType(_class).add([_class(**item) for item in result])
         return result
 
     @property
@@ -447,16 +450,26 @@ class Connection():
         Debug("Formating Query")
         query = self.__format_select_query__()
         result = self._conn.fetchall(query)
-        result = ListType(self._class).add([self._class(aliases=self._alias, **item) for item in result])
+        result = datatype.ListType(self._class).add([self._class(aliases=self._alias, **item) for item in result])
         if self._include:
             for item in result:
                 for _include in self._include:
                     item[_include].__reset__()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print(item[_include].__class__)
+                    print()
+                    print()
+                    print()
+                    print()
                     item.__metadata__['relasionships'][_include] = None if not 'List' in item[_include].__class__.__name__ else []
                     _stetament_include = self.__format_include_query__(item, _include)
-                    _include_result = self._conn.fetchall(_stetament_include)
-                    if len(_include_result)>0:
-                        item.add(_include, _include_result)
+                    if _stetament_include:
+                        _include_result = self._conn.fetchall(_stetament_include)
+                        if len(_include_result)>0:
+                            item.add(_include, _include_result)
         return result
 
     @property
@@ -472,9 +485,9 @@ class Connection():
                 item[_include].__reset__()
                 item.__metadata__['relasionships'][_include] = None if not 'List' in item[_include].__class__.__name__ else []
                 _stetament_include = self.__format_include_query__(item, _include)
-                _include_result = self._conn.fetchall(_stetament_include)
-                item.add(_include, _include_result)
-
+                if _stetament_include:
+                    _include_result = self._conn.fetchall(_stetament_include)
+                    item.add(_include, _include_result)
         return item
 
 
