@@ -156,7 +156,7 @@ class Json(ValidateValue):
 
     def __setattr__(self, attr, data, check=True):
         if check and attr == "value" and data is not None:
-            if not isinstance(data, dict) or not isinstance(data, str):
+            if not isinstance(data, dict) and not isinstance(data, str):
                 raise Exception("requires Dict or String")
             if isinstance(data, dict):
                 data = str(data)
